| SeaSondeRAPM_amplitude_and_phase_corrections_step_text | R Documentation |
This function generates a message indicating the amplitude and phase corrections applied to the APM.
SeaSondeRAPM_amplitude_and_phase_corrections_step_text(
amplitude1,
amplitude2,
phase1,
phase2
)
amplitude1 |
Amplitude correction for the first channel. |
amplitude2 |
Amplitude correction for the second channel. |
phase1 |
Phase correction (in degrees) for the first channel. |
phase2 |
Phase correction (in degrees) for the second channel. |
A character string detailing the applied amplitude and phase corrections.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.