| process_version_header | R Documentation |
This function processes a specified version of the SeaSonde file header. It identifies the appropriate header function for the given version, processes the header, and then updates the accumulating pool of header data. Specifically:
process_version_header(
pool,
version,
specs,
connection,
endian = "big",
prev_data = NULL
)
pool |
List. An accumulating list of processed headers from prior versions. |
version |
Integer. The specific version of the header to be processed. E.g., for version 3,
the function |
specs |
List. Header specifications for each version. Each entry should correspond to a version number and contain the required information to process that version's header. |
connection |
Connection object. The file connection pointing to the SeaSonde file. |
endian |
Character string. Specifies the byte order for reading data. Can be "big" (default) |
prev_data |
previous header data or "little". Use the appropriate value depending on the system architecture and the file's source. |
For fields in the current header that overlap with the accumulated pool, the current header's values overwrite those in the pool.
Fields that are unique to the current header are appended to the pool.
List. A combination of the initial pool and the processed header for the given version.
Fields in the current header will overwrite or append to the pool as described above.
This function assumes that the desired version-specific seasonder_readSeaSondeCSFileHeaderV*
functions are available in the global environment.
seasonder_readSeaSondeCSFileHeaderV2
seasonder_readSeaSondeCSFileHeaderV3
seasonder_readSeaSondeCSFileHeaderV4
seasonder_readSeaSondeCSFileHeaderV5
seasonder_readSeaSondeCSFileHeaderV6
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.