View source: R/SeaSondeRCS_MUSIC.R
| seasonder_MUSICComputePropDualSols | R Documentation |
This function calculates the proportion of "dual" solutions in the MUSIC data
associated with a given SeaSondeRCS object. It updates the object with the computed
proportion as a new attribute.
seasonder_MUSICComputePropDualSols(seasonder_cs_object)
seasonder_cs_object |
A |
The function performs the following steps:
Extracts the MUSIC data from the provided SeaSondeRCS object.
Computes the proportion of entries in the retained_solution column of the MUSIC data
that are labeled as "dual".
Updates the SeaSondeRCS object by adding the computed proportion as an attribute
using seasonder_setSeaSondeRCS_MUSIC_dual_solutions_proportion.
A SeaSondeRCS object with the calculated proportion of "dual" solutions stored as
an attribute. This attribute can be accessed using a relevant getter function.
seasonder_getSeaSondeRCS_MUSIC to retrieve the MUSIC data.
seasonder_setSeaSondeRCS_MUSIC_dual_solutions_proportion to set the computed proportion.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.