| seasonder_defaultMUSIC_parameters | R Documentation |
This function returns the default parameters for the MUSIC algorithm used in the SeaSondeR package.
seasonder_defaultMUSIC_parameters()
The default parameters are:
40: Threshold used in seasonder_MUSICCheckEigenValueRatio.
20: Threshold used in seasonder_MUSICCheckSignalPowers.
2: Threshold used in seasonder_MUSICCheckSignalMatrix.
20: Threshold used in seasonder_MUSICCheckBearingDistance.
A numeric vector containing the default parameters for the MUSIC algorithm:
c(40, 20, 2, 20).
seasonder_MUSICTestDualSolutions to understand the parameters in context.
# Retrieve default parameters
params <- seasonder_defaultMUSIC_parameters()
print(params)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.