| seasonder_getSeaSondeRCS_antenna_SSdata | R Documentation |
This function extracts the self-spectra (SSA) data matrix for a given antenna from a SeaSondeRCS object.
seasonder_getSeaSondeRCS_antenna_SSdata(seasonder_cs_object, antenna)
seasonder_cs_object |
A SeaSondeRCS object containing spectral data. |
antenna |
An integer specifying the antenna number (1, 2, or 3). |
The function constructs the matrix name dynamically by appending the antenna number to the prefix
"SSA" (e.g., "SSA1", "SSA2", or "SSA3"). It then retrieves the corresponding
matrix from the SeaSondeRCS data using seasonder_getSeaSondeRCS_dataMatrix.
A matrix containing the self-spectra data for the specified antenna. If the antenna number is invalid, an error is thrown.
seasonder_getSeaSondeRCS_dataMatrix for extracting specific data matrices.
seasonder_getSeaSondeRCS_data for retrieving the complete data structure.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.