| seasonder_initializeAttributesSeaSondeRAPM | R Documentation |
This function initializes attributes for a SeaSondeRAPM object, including metadata and properties.
seasonder_initializeAttributesSeaSondeRAPM(calibration_matrix, ...)
calibration_matrix |
A 2 x b complex matrix, where b is the number of bearings for calibration. |
... |
Additional named attributes that may override the defaults. |
The function initializes the following attributes:
quality_matrix: A 3 x b complex matrix for quality data, where b is the number of bearings.
BEAR: A numeric vector for bearings (degrees CCW from the site bearing).
Type: Character string for antenna pattern type.
Creator: Object creator name. Default is an empty character vector.
SiteName: Site name (not the same as SiteCode). Default is an empty character vector.
SiteOrigin: Numeric vector with two elements representing the Station GPS location. Default is c(0,0).
FileName: Default is an empty character vector.
CreateTimeStamp: APM file creation time. Default is current system date and time.
ProcessingSteps: Processing steps applied to this object. Default is an empty character vector.
AmplitudeFactors: Numeric vector with two elements for the amplitude factors. Default is c(0,0).
AntennaBearing: Site bearing (CW degrees from true north). Default is an empty numeric vector.
StationCode: 4-character station code. Default is an empty character vector.
BearingResolution: In degrees. Default is an empty numeric vector.
Smoothing: Numeric vector indicating smoothing applied to the antenna pattern. Default is an empty numeric vector.
CommentLine: Metadata lines in the data file not matching any other attribute. Default is an empty character vector.
FileID: File's UUID. Default is an empty character vector.
PhaseCorrections: Numeric vector with two elements for phase corrections. Default is c(0,0).
A list containing initialized attributes for a SeaSondeRAPM object.
seasonder_createSeaSondeRAPM,
seasonder_validateAttributesSeaSondeRAPM
# Initialize attributes for a dummy calibration matrix
attrs <- seasonder_initializeAttributesSeaSondeRAPM(matrix(1:6, nrow = 3))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.