View source: R/SeaSondeRCS_FOR.R
| seasonder_setSeaSondeRCS_FOR_MAXP.bin | R Documentation |
This function assigns the Doppler bin indices corresponding to the maximum power (MAXP.bin)
for each range cell in the First Order Region (FOR) to the SeaSondeRCS object.
seasonder_setSeaSondeRCS_FOR_MAXP.bin(seasonder_cs_object, FOR_MAXP.bin)
seasonder_cs_object |
A |
FOR_MAXP.bin |
A list containing the Doppler bin indices of the maximum power for each range cell. |
The maximum power bin (MAXP.bin) represents the Doppler bin index at which the highest spectral power
was detected in the first-order region. This information is used to refine first-order boundary detection.
Validation Considerations:
The function does not currently validate the format of FOR_MAXP.bin.
Future improvements should ensure that FOR_MAXP.bin consists of integer values corresponding to Doppler bins.
The updated SeaSondeRCS object with the MAXP.bin values stored in the FOR_data attribute.
seasonder_findFORNulls for computing MAXP.bin.
seasonder_setSeaSondeRCS_FOR_MAXP for setting maximum power values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.